@@ -67,6 +67,10 @@ print "LESSOPEN=\"$ENV{LESSOPEN}\"\n\n" if $noaction;
 $ENV{LESSQUIET} =1;
 $ENV{LESSCOLORIZER} = 'vimcolor';
 $ENV{LANG} = 'en_US.UTF-8';
+$ENV{LC_ALL} = 'en_US.UTF-8';
+$ENV{TZ} = '';
+(my $dir = $0) =~ s|/[^/]*$|:|;
+$ENV{PATH} = $dir . $ENV{PATH};
 
 my $duration = time();
 my ($retcode, $sumok, $sumignore, $sumnok, $num) = (0, 0, 0, 0, 0);
@@ -118,7 +122,7 @@ while (<DATA>) {
 	map {s/html_converter/w3m,lynx,elinks,html2text/} @needed;
 	if ($noaction) {
 		my $needed_str = $needed ? " ($needed)" : '';
-		print $verbose ? "$num $cmd $needed_str" : $cmd, "\n";
+		print $verbose ? "$num $cmd $needed_str\n" : "$num $cmd\n";
 		next;
 	}
 	my $ignore = 0;
@@ -367,7 +371,7 @@ less tests/filter.tgz:test_xls		# xls (old), needs in2csv|xls2csv|libreoffice,ht
 = test
 less tests/filter.tgz:test_ooffice1	# openoffice1 (very old), needs sxw2txt|libreoffice
 = test
-less tests/filter.tgz:test_nroff	# man pages etc (nroff), needs groff
+less tests/filter.tgz:test_nroff	# man pages etc (nroff), needs groff|mandoc
 ~ .* test \(1\)
 less tests/filter.tgz:test_rtf		# rtf, needs unrtf|libreoffice
 ~ test
@@ -436,17 +440,21 @@ c test=a
 ### github issues (solved and unsolved) and other test cases
 LESSCOLORIZER=code2color less tests/special.tgz:a-r-R.pl	# colorize works within archives
 c sub
+LESSCOLORIZER=pygmentize less tests/filter.tgz:test_dtb	# device tree blob, needs dtc
+c test
 less $T/tests/a-r-R.pl		# do not call vimcolor with -l extension git #77
 c sub
 LESS= less $T/tests/a-r-R.pl		# name contains -r or -R git #78
 = sub test {}
-less $T/tests/test_zip:non-existent-file	# nonexisting file in a zip archive git issue #1
+less $T/tests/test_zip:non-existent-file	# nonexisting file in a zip archive git #1
 ~ 
+LESS= less tests/dir.zip	# do not colorize listing git #140
+~ drwxrwxr-x  0 1000   1000        0 Dec 12 20:56 dir/
 less $T/tests/test\ \;\'\"\[\(\{ok		# file name with chars such as ", ' ...
 = test
 less tests/special.tgz:test\ \;\'\"\[\(\{ok	# archive having a file with chars from [ ;"'] etc. in the name
 = test
-less $T/tests/test\[a\]\(b\)\{c\}.zip	# file name with parens, brackets, braces git issue 69
+less $T/tests/test\[a\]\(b\)\{c\}.zip	# file name with parens, brackets, braces git #69
 ~ .*test\[a\]\(b\)\{c\}
 less $T/tests/test\[a\]\(b\)\{c\}.zip:'test\[a\]\(b\)\{c\}'	# contained file with parens etc.
 = test
@@ -458,7 +466,7 @@ less $T/tests/special.tgz=aaa::b::c::d	# file name with colon (use alternate sep
 = test
 less $T/tests/symlink			# symbolic link to file name with special chars
 = test=a
-cat $T/tests/test_zip|less			# can use pipes with LESSOPEN =|-... git issue #2
+cat $T/tests/test_zip|less			# can use pipes with LESSOPEN =|-... git #2
 ~ .*10240.*
 cat $T/tests/test_zip|less - :tests/test.tar	# extract files from piped file
 ~ .* tests/textfile
